@@ -1,11 +1,33 @@
 #
-# $Id: Constants.pm,v 0.35 1999/07/14 16:35:43 dankogai Exp dankogai $
+# $Id: Constants.pm,v 0.40 1999/07/15 18:26:18 dankogai Exp dankogai $
 #
 
+=head1 NAME
+
+Jcode::Constants -- Constants used in Jcode
+
+=head1 DESCRIPTION
+
+This module is for internal use by Jcode modules.
+
+=head1 COPYRIGHT
+
+Copyright 1999 Dan Kogai <dankogai@dan.co.jp>
+
+This library is free software; you can redistribute it
+and/or modify it under the same terms as Perl itself.
+
+=cut
+
 package Jcode::Constants;
-require 5.000;
-use Carp;
+
 use strict;
+use vars qw($RCSID $VERSION);
+
+$RCSID = q$Id: Constants.pm,v 0.40 1999/07/15 18:26:18 dankogai Exp dankogai $;
+$VERSION = do { my @r = (q$Revision: 0.40 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+
+use Carp;
 
 BEGIN {
     use Exporter;
@@ -25,10 +47,10 @@ my %_0208 = (
 		);
 
 %CHARCODE = (
-	     UNDEF_EUC  => '\xa2\xae',     #  in EUC
-	     UNDEF_SJIS => '\x81\xac',     #  in SJIS
-	     UNDEF_JIS  => '\xa2\xf7',     #  -- used in unicode
-	     UNDEF_UNICODE  => '\x20\x20', #  -- used in unicode
+	     UNDEF_EUC  =>     "\xa2\xae",  #  in EUC
+	     UNDEF_SJIS =>     "\x81\xac",  #  in SJIS
+	     UNDEF_JIS  =>     "\xa2\xf7",  #  -- used in unicode
+	     UNDEF_UNICODE  => "\x20\x20",  #  -- used in unicode
 	 );
 
 %ESC =  (
@@ -40,16 +62,16 @@ my %_0208 = (
 
 %RE =
     (
-     BIN       => '[\000-\006\177\377]',
-     EUC_0212  => '\217[\241-\376][\241-\376]',
-     EUC_C     => '[\241-\376][\241-\376]',
-     EUC_KANA  => '\216[\241-\337]',
+     BIN       => '[\x00-\x06\x7f\xff]',
+     EUC_0212  => '\x8f[\xa1-\xfe][\xa1-\xfe]',
+     EUC_C     => '[\xa1-\xfe][\xa1-\xfe]',
+     EUC_KANA  => '\x8e[\xa1-\xdf]',
      JIS_0208  =>  "$_0208{1978}|$_0208{1983}|$_0208{1990}",
      JIS_0212  => "\e" . '\$\(D',
      JIS_ASC   => "\e" . '\([BJ]',     
      JIS_KANA  => "\e" . '\(I',
-     SJIS_C    => '[\201-\237\340-\374][\100-\176\200-\374]',
-     SJIS_KANA => '[\241-\337]',
+     SJIS_C    => '[\x81-\x9f\xe0-\xfc][\x40-\x7e\x80-\xfc]',
+     SJIS_KANA => '[\xa1-\xdf]',
      );
 
 #
